#
# spec file for package scout
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cnfrepo zypp
Name:           scout
Version:        0.2.7+20230124.b4e3468
Release:        2.3
Summary:        Indexing Package Properties
License:        MIT
Group:          System/Packages
URL:            https://github.com/openSUSE/scout/
Source:         %{name}-%{version}.tar.xz
BuildRequires:  gettext
BuildRequires:  python3
BuildRequires:  python3-rpm
BuildRequires:  python3-solv
BuildRequires:  python3-xml
Requires:       python3
Requires:       python3-solv >= 0.6.0
Requires:       python3-xml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The scout tool helps with indexing of various package properties.

%package command-not-found
Summary:        Command Not Found extension for shell
Group:          System/Packages
Requires:       python3
Requires:       python3-rpm
Requires:       scout = %{version}-%{release}
Obsoletes:      command-not-found < %{version}-%{release}
Provides:       command-not-found
Conflicts:      command-not-found

%description command-not-found
The "command not found" message is not very helpful. If e.g. the unzip
command is not found but it's available in a package, it would be very
interesting if the system could tell that the command is currently not
available, but installing a package would provide it.

%prep
%autosetup -p1

%build
# compile scripts
python3 -mcompileall .

%install
# --- scout ---
# install python scripts
mkdir -p %{buildroot}%{python3_sitelib}/%{name}/__pycache__
shopt -s extglob
cp -a scout/!(foo).py %{buildroot}%{python3_sitelib}/%{name}
cp -a scout/__pycache__/!(foo).pyc %{buildroot}%{python3_sitelib}/%{name}/__pycache__
# install data files
install -D -m 0644 repos.conf %{buildroot}%{_datadir}/%{name}/repos.conf
# install scout binary
install -D -m 0755 scout-cmd.py %{buildroot}%{_bindir}/%{name}
# install bash completion
install -D -m 0644 scout-bash-completion %{buildroot}%{_sysconfdir}/bash_completion.d/scout.sh
# install manpage
install -D -m 0644 doc/scout.1 %{buildroot}%{_mandir}/man1/scout.1
# install and find languages
for po in i18n/scout/*.po; do
    pofile=${po##*/}
    lang=${pofile%.po}
    msgfmt $po -o i18n/scout/$lang.mo
    install -D -m 0644 i18n/scout/$lang.mo %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/scout.mo
done
%find_lang scout

# --- command-not-found ---
install -D -m 0755 handlers/bin/command-not-found %{buildroot}%{_bindir}/command-not-found
ln -sf command-not-found %{buildroot}%{_bindir}/cnf
# install manpage
install -D -m 0644 doc/command-not-found.1 %{buildroot}%{_mandir}/man1/command-not-found.1
ln -sf command-not-found.1.gz %{buildroot}%{_mandir}/man1/cnf.1.gz
# install shell handlers
for shell in bash zsh; do
    install -D -m 644 handlers/bin/command_not_found_${shell} %{buildroot}%{_sysconfdir}/${shell}_command_not_found
    sed -i 's:__REPO__:%{cnfrepo}:' %{buildroot}%{_sysconfdir}/${shell}_command_not_found
done
# install and find languages
for po in i18n/command-not-found/*.po; do
    pofile=${po##*/}
    lang=${pofile%.po}
    msgfmt $po -o i18n/command-not-found/$lang.mo
    install -D -m 0644 i18n/command-not-found/$lang.mo %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/command-not-found.mo
done
%find_lang command-not-found
%python3_fix_shebang

%files -f scout.lang
%defattr(-,root,root)
%doc AUTHORS LICENSE README TODO doc/scout.html doc/scout.pdf
%{_bindir}/%{name}*
%{python3_sitelib}/%{name}
%{_datadir}/%{name}
%config %{_sysconfdir}/bash_completion.d/*
%{_mandir}/man1/scout*

%files command-not-found -f command-not-found.lang
%defattr(-,root,root)
%doc handlers/bin/README
%{_bindir}/cnf
%{_bindir}/command-not-found
%config %{_sysconfdir}/*_command_not_found
%{_mandir}/man1/cnf*
%{_mandir}/man1/command-not-found*

%changelog
* Fri Mar  8 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Tue Jan 24 2023 bwiedemann@suse.com
- Update to version 0.2.7+20230124.b4e3468:
  * Bump version to v0.2.7
  * allow multiple baseurls in repo file
  * remove deprecated class
  * Translated using Weblate (Macedonian, German, Ukrainian)
* Tue Nov 30 2021 aplanas@suse.com
- Update to version 0.2.6+20211130.022a45c:
  * Fix finding packages from repo with / in name
  * Translated using Weblate (French, Slovak, Spanish)
* Sat Apr 24 2021 bwiedemann@suse.com
- Update to version 0.2.5+20210424.3bff388:
  * Work with newer python3-rpm
* Sat Mar 27 2021 Sasi Olin <hel@lcp.world>
- Rename command-not-found to scout-command-not-found and add command-not-found provides
* Sat Mar 27 2021 bwiedemann@suse.com
- Update to version 0.2.4+20210325.6c2d9f3:
  * Fix output of cnf ambiguous install (boo#1183980)
  * Translated using Weblate (Indonesian, Catalan)
  * Stop ignoring exceptions
* Wed Jan 15 2020 bwiedemann@suse.com
- Update to version 0.2.3+20200115.5b1005a:
  * Bump version to 0.2.3
  * Return success if found
  * Update docs
  * cnf: allow to install found package
  * Translated using Weblate (Finnish, Estonian, Norwegian Nynorsk)
* Thu Jun 13 2019 bwiedemann@suse.com
- Update to version 0.2.2+20190613.e6c2668:
  * Bump version to 0.2.2
  * Fix bug where sbin packages would print as bytes strings (boo#1135598)
  * Newly generated po files (new line numbers).
  * The make_trans script did not work, because strings were not marked because of eval
  * Fix bash i18n support. The translations are expanded during definition of the function, when LANG is not yet set. Use eval to postpone it.
  * Fix i18n support.
  * Updated translations
* Thu Oct  4 2018 opensuse-packaging@opensuse.org
- Update to version 0.2.1+20181004.20a0aae:
  * Unicode versions of gettext are not for Python 3
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Japanese)
  * Clean empty strings in untranslated po files.
  * Update po files.
  * Mark translatable strings
  * Delete temporary files
  * Get the make_trans script to work
* Wed Sep 19 2018 opensuse-packaging@opensuse.org
- Update to version 0.2.1+20180914.017a078:
  * Avoid running command-not-found with python2 (boo#1108565)
* Mon Aug 13 2018 opensuse-packaging@opensuse.org
- Initial Python3 support (bsc#1077238)
- Update to version 0.2.1+20180813.59519f8:
  * scout-cmd: convert dict keys into a list
  * scout-cmd: __iter__ is part of a string
  * scout-cmd: KeyboardInterrupt lives out of a module
  * scout: migrate bin to Python3
  * Do not interpolate SQL strings
  * Use system Python 3 interpreter
  * scount-cmd: Initial support for Python 3
  * data-gen: Initial support to Python 3
  * tests: Initial support for Python 3
  * cnf: initial port to Python 3
  * Move setup.py to distutils and fix package_data
  * Add setup.py
  * Replace multiple unclear "zypper refresh" error messages with a helpful warning
  * Fix lookup of solv-file path for repos with '/' in name (bsc#1037101)
  * Translated using Weblate (Hindi)
  * Translated using Weblate (Hindi)
  * Translated using Weblate (Hindi)
  * Translated using Weblate (Galician)
  * Translated using Weblate (Galician)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
* Wed Jan  3 2018 opensuse-packaging@opensuse.org
- Update to version 0.1.1+20180103.0595254:
  * allow for multiple repos to be in one .repo file
  * Parse repo files for repo name (boo#980393)
  * Updated translations (Spanish, Norwegian Nynorsk)
* Fri Jun 30 2017 opensuse-packaging@opensuse.org
- Update to version 0.1.1+20170630.f55550e:
  * drop outdated DBs
* Thu Jun 29 2017 opensuse-packaging@opensuse.org
- Update to version 0.1.1+20170629.b80f023:
  * update translations using Weblate (Swedish, Chinese, French, Greek, Polish,
    Indonesian, Persian, Italian, Bulgarian, Lithuanian, Danish, Spanish)
  * zsh: avoid cnf being triggered on every false result
  * zsh: improve handler hooking
  * zsh: expect command to be quoted
  * zsh: define function with two names
  * detect if we have no repos configured (bsc#1037101)
  * call zypper refresh when solv file missing (bsc#1037101)
  * Version 0.1.1
* Mon May 30 2016 opensuse-packaging@opensuse.org
- Update to version 0.1.0+20160523.472154b:
  * Translated using Weblate (German)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Norwegian Nynorsk)
  * Translated using Weblate (German)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (French)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Swedish)
* Mon May 30 2016 tchvatal@suse.com
- Cleanup a bit to have the spec readable and point to proper url
* Fri Oct 23 2015 dimstar@opensuse.org
- Update to version 0.1.0+20151023:
  + adapt to Dataiterator changes in libsolv-0.6.0 (boo#951977)
  + Updated translations.
* Fri Sep 25 2015 dimstar@opensuse.org
- Update to version 0.1.0+20150925:
  + Update translations based on https://svn.opensuse.org/svn/opensuse-i18n/trunk/lcn/ - REV 92845
    (boo#906691).
- Change to source service (disabled), checking out from git.
* Thu Apr 10 2014 mls@suse.de
- adapt to Dataiterator changes in libsolv-0.6.0
* Mon Mar  3 2014 mls@suse.de
- port from libsatsolver to libsolv [fate#316955]
- fix bnc#714558: support utf-8 chars in solvable names
* Thu Apr  5 2012 ke@suse.de
- scout.spec: minor cleanup.
* Wed Jun  2 2010 prusnak@opensuse.org
- update translations
* Wed Apr 28 2010 prusnak@suse.cz
- also check the file name, not only the package name while testing
  whether the package is installed
- add TEXTDOMAINDIR
- fix localization of one msg
* Mon Mar 15 2010 prusnak@suse.cz
- update repositories list
* Fri Sep 25 2009 prusnak@suse.cz
- added translations to scout:
    da es fi fr hu it ja km ko nl pl pt_BR ru uk zh_TW
- added translations to c-n-f:
    da es fi fr gl hu it ja km ko nl pl pt_BR ru uk wa zh_TW
* Wed Sep  9 2009 prusnak@suse.cz
- print message when inside midnight commander, don't just quit
* Tue Aug 18 2009 prusnak@suse.cz
- don't advise to use sudo when running as root
- fix manpages in packages
- fixed typos in cnf manpage
- escape the term before creating regexp
- suppress KeyboardInterrupt traceback after Ctrl+C
- refine text messages
- modify the search term before query
* Mon Mar 23 2009 prusnak@suse.cz
- command-not-found:
  * create cnf as symlink to command-not-found
  * print info line before the search
* Mon Feb  9 2009 prusnak@suse.cz
- scout:
  * fixed proper encoding of an error msg [bnc#460705]
  * added -p option (inverse search by package name)
  * don't exit successfully when nothing is found [bnc#466397]
  * always return EX_NOTFOUND [bnc#466397]
- command-not-found:
  * don't load all scout modules
  * more tests in bash handler (don't run in subshell or pipe)
  * check /usr/sbin and /sbin for binaries before using satsolver
  * require COMMAND_NOT_FOUND_AUTO to be set to run search directly
  * add documentation
* Tue Nov 18 2008 prusnak@suse.cz
- check number of unique packages in command-not-found
* Sat Nov  8 2008 prusnak@suse.cz
- don't write stacktraces when Ctrl+C is pressed
* Mon Nov  3 2008 prusnak@suse.cz
- modify zypp search to work with new python-satsolver
* Fri Oct 10 2008 prusnak@suse.cz
- print output of c-n-f to stderr
- remove no longer needed python-satsolver workarounds
- do not add zypp among repositories when python-satsolver not installed
- fix -r option
* Tue Sep 23 2008 prusnak@suse.cz
- do not run command-not-found handler inside Midnight Commander
* Fri Sep 19 2008 prusnak@suse.cz
- fixed bash completion and typo
* Fri Sep 12 2008 prusnak@suse.cz
- optimized zypp repository search
- fixed module instance creation in command-not-found
* Tue Sep  9 2008 prusnak@suse.cz
- added gettext support
* Mon Aug 18 2008 schwab@suse.de
- Fix name of completions file.
* Wed Aug  6 2008 prusnak@suse.cz
- updated to 0.1.0
  * enabled search in zypp repositories
* Thu Jun 12 2008 prusnak@suse.cz
- created package
